import re, os, time, sys

def deleteFile(path):
    cpt = 0
    while True and cpt < 300:  # try catch because of deleting the file that is sometimes not released soon enough
        try:
            os.remove(path)
        except:
            time.sleep(1)
            cpt = cpt + 1
        else:
            break

def isFloat(string):
    try:
        float(string)
        return True
    except ValueError:
        return False
        
def analyzeAudioFeature(AFlist, wavePath, featureDumpFileName, featureSize):
    dumpFilePath = wavePath.replace('.wav', featureDumpFileName)
    feature = [0 for i in range(featureSize)]
    cpt = 0
    
    dumpFile = open(dumpFilePath, 'r')
    
    for line in dumpFile:
        cpt = cpt + 1
        entries = re.split('\t', line.strip())
        for idx, column in enumerate(entries):
            if(isFloat(column)):
                feature[idx] = feature[idx] + float(column)
            
    dumpFile.close()
    
    for i in range(featureSize):
        AFlist.append(feature[i]/cpt)
    
    deleteFile(dumpFilePath)
    
def analyzeAudioFeaturesDumpFiles(AFlist, wavePath):
    # Asymmetry
    analyzeAudioFeature(AFlist, wavePath, '_asymmetry.txt', 1)
    # Asymmetry envelope
    analyzeAudioFeature(AFlist, wavePath, '_asymmetry_env.txt', 1)
    # Centroid
    analyzeAudioFeature(AFlist, wavePath, '_centroid.txt', 1)
    # Centroid envelope
    analyzeAudioFeature(AFlist, wavePath, '_centroid_env.txt', 1)
    # Energy
    analyzeAudioFeature(AFlist, wavePath, '_energy.txt', 1)
    # Energy Mel Band
    analyzeAudioFeature(AFlist, wavePath, '_energymelband.txt', 24)
    # Flatness
    analyzeAudioFeature(AFlist, wavePath, '_flatness.txt', 1)
    # Flatness Band
    analyzeAudioFeature(AFlist, wavePath, '_flatness_band.txt', 24)
    # Flatness Cedric
    analyzeAudioFeature(AFlist, wavePath, '_flatness_cedric.txt', 1)
    # Flatness Cedric envelope
    analyzeAudioFeature(AFlist, wavePath, '_flatness_cedric_env.txt', 1)
    # MFCC
    analyzeAudioFeature(AFlist, wavePath, '_mfcc.txt', 12)
    # Roll Off
    analyzeAudioFeature(AFlist, wavePath, '_roll_off.txt', 1)
    # Wavelet transform max
    analyzeAudioFeature(AFlist, wavePath, '_wtf_max.txt', 12)
    # Wavelet transform max2stdratio
    analyzeAudioFeature(AFlist, wavePath, '_wtf_max2stdratio.txt', 12)
    # Wavelet transform mean
    analyzeAudioFeature(AFlist, wavePath, '_wtf_mean.txt', 12)
    # Wavelet transform min
    analyzeAudioFeature(AFlist, wavePath, '_wtf_min.txt', 12)
    # Wavelet transform std
    analyzeAudioFeature(AFlist, wavePath, '_wtf_std.txt', 12)
    # Audio Zero Crossing
    analyzeAudioFeature(AFlist, wavePath, '_zcr.txt', 1)
    
    #print(str(len(AFlist)) + ' audio features read')

def concatenateAudioFeatures(waveFile):
    print('Merging files from ' + waveFile)
    
    AFlist = []
    analyzeAudioFeaturesDumpFiles(AFlist, waveFile)
    deleteFile(waveFile)
    
    # Write audio features
    outputAudioFeaturesPath = waveFile.replace('.wav', '.txt')
    f = open(outputAudioFeaturesPath, 'w')
    for item in AFlist:
        f.write("%s\t" % item)
    f.close()
    
if __name__ == '__main__':
    concatenateAudioFeatures(*sys.argv[1:])