#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
Convert an HTML page to PDF
'''
import logging
import logging.config
import StringIO
import argparse

from weasyprint import HTML


try:
    logging.config.fileConfig('loggingpy.conf', disable_existing_loggers=False)
except Exception:
    # try to set up a default logger
    logging.basicConfig(level=logging.WARNING, format="%(filename)s:%(name)s:%(lineno)d %(levelname)s %(message)s")


def convert_HTML_to_PDF(HTML_string=None, PDF_file=None, PDF_file_name=None):
    '''
    Convert an HTML page to PDF
    '''
    logger = logging.getLogger("convert_HTML_to_PDF")

    if PDF_file is None:
        PDF_file = StringIO.StringIO()
    ps = HTML(string=HTML_string)
    ps.write_pdf(target=PDF_file)
    if PDF_file_name is not None:
        try:
            with open(PDF_file_name, 'w+b') as x:
                x.write(PDF_file.getvalue())
        except Exception:
            logger.warning(u"Warning: could not write to %s", PDF_file_name)
    return PDF_file.getvalue()


def parse_args():
    """Argument parser for HTML to PDF"""
    parser = argparse.ArgumentParser(description="Convert an HTML file to a PDF")
    parser.add_argument("--input", "-i", dest='input',
                        type=argparse.FileType('r'), help="HTML Filename",
                        default=".")
    parser.add_argument("--output", "-o", dest='output',
                        type=argparse.FileType('w'), help="PDF Output File",
                        default=None)
    return parser.parse_args()


def main():
    """main for convert_HTML_to_PDF"""
    args = parse_args()
    convert_HTML_to_PDF(HTML_string=args.input.read(), PDF_file_name=args.output.name)


if __name__ == "__main__":
    main()
